IsolatesTask class

use isolates to run functions on differeent thread in dart its is very useful for long running task like uploading images to server.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

useIsolate(dynamic args, dynamic functionThatIsToBeRunOnIsolates) → Future